.nav-wrapper
  background-color: $off-white
  background-image: linear-gradient(to right, $off-white, $light-grey)
  padding-bottom: 10px
  border-bottom: $BORDER

  a
    color: $black
    font-weight: 800
    font-family: monospace
    border-bottom: none
    &:hover
      font-weight: 200
      color: $white
      border-bottom: none

  li
    border-left: $BORDER

  .brand-logo
    height: 100%

    svg
      height: 100%
      position: relative
      padding: 5px 10px