{% extends 'base.html' %}

{% block content %}
    <div class="col s12">
        <div class="card">
            <div class="card-content">
                <form method="post" action="{{ request.path }}">
                    {% csrf_token %}

                    {% block form %}{% endblock %}

                    <div align="center" class="row">
                        <button class="btn waves-effect waves-light" type="submit" name="action">
                            Submit
                        </button>
                    </div>
                </form>
            </div>
        </div>
    </div>
{% endblock %}