/* overide material design vendor */
.material-icons
  font-size: inherit
  vertical-align: middle
  line-height: unset

.input-field.col label
  left: 0.5em !important

label
  font-size: 0.5em !important
  color: $black
  cursor: default !important

.btn
  text-transform: none !important
  position: relative
  transition: all 0.3s ease 0s
  top: 0

  &:hover
    box-shadow: none
  text-shadow: 0 0 20 $black

.btn-small
  height: 24px
  line-height: 24px
  padding: 0 0.7rem
  font-size: 10px
  background-color: $light-grey

  &:hover
    background-color: $grey

.toast
  a
    color: $green

  span
    color: $white !important

.input-field
  label
    width: 100%
    left: 5px !important
    font-size: 20px !important
    top: -5px
