$black: #1c1c1c
$white: #f6f6f6
$grey: #474747
$light-grey: #b3b3b3
$off-white: #e7e7e7
$red: #bc2122
$green: #67A062
$off-yellow: #DCC698
$orange: #bc7921
$blue: #2B6F75

$nav-padding: 10px
$BORDER: $black 3px solid