.break-all
  word-break: break-all

.flash
  -webkit-animation: flickerAnimation 0.4s infinite
  -moz-animation: flickerAnimation 0.4s infinite
  -o-animation: flickerAnimation 0.4s infinite
  animation: flickerAnimation 0.4s infinite

.r
  background-color: $red !important

.g
  background-color: $green !important

.error
  color: $red !important

.success, .success *
  color: $green !important

img.svg
  visibility: hidden